==> ansible-4.0.0-1-any.pkg.tar.xz: usr/lib/python3.9/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_dvmdb_script.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2020 Fortinet, Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_dvmdb_script
short_description: Script table.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.10"
author:
    - Link Zheng (@chillancezen)
    - Jie Xue (@JieX19)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded

options:
    bypass_validation:
        description: only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters
        required: false
        type: bool
        default: false
    workspace_locking_adom:
        description: the adom to lock for FortiManager running in workspace mode, the value can be global and others including root
        required: false
        type: str
    workspace_locking_timeout:
        description: the maximum time in seconds to wait for other user to release the workspace lock
        required: false
        type: int
        default: 300
    state:
        description: the directive to create, update or delete an object
        type: str
        required: true
        choices:
          - present
          - absent
    rc_succeeded:
        description: the rc codes list with which the conditions to succeed will be overriden
        type: list
        required: false
    rc_failed:
        description: the rc codes list with which the conditions to fail will be overriden
        type: list
        required: false
    adom:
        description: the parameter (adom) in requested url
        type: str
        required: true
    dvmdb_script:
        description: the top level parameters set
        required: false
        type: dict
        suboptions:
            content:
                type: str
                description: 'The full content of the script result log.'
            desc:
                type: str
                description: no description
            filter_build:
                type: int
                description: 'The value will be ignored in add/set/update requests if filter_ostype is not set. It has no effect if target is "adom_database".'
            filter_device:
                type: int
                description: 'Name or id of an existing device in the database. It has no effect if target is "adom_database".'
            filter_hostname:
                type: str
                description: 'The value has no effect if target is "adom_database".'
            filter_ostype:
                type: str
                default: 'unknown'
                description: 'The value has no effect if target is "adom_database".'
                choices:
                    - 'unknown'
                    - 'fos'
            filter_osver:
                type: str
                default: 'unknown'
                description: 'The value will be ignored in add/set/update requests if filter_ostype is not set. It has no effect if target is "adom_database".'
                choices:
                    - 'unknown'
                    - '4.00'
                    - '5.00'
            filter_platform:
                type: str
                description: 'The value will be ignored in add/set/update requests if filter_ostype is not set. It has no effect if target is "adom_database".'
            filter_serial:
                type: str
                description: 'The value has no effect if target is "adom_database".'
            modification_time:
                type: str
                description: 'It is a read-only attribute indicating the time when the script was created or modified. The value will be ignored in add/set/...'
            name:
                type: str
                description: no description
            script_schedule:
                description: no description
                type: list
                suboptions:
                    datetime:
                        type: str
                        description:
                         - 'Indicates the date and time of the schedule. It should follow the following format for each scheduling type:'
                         - 'onetime: "YYYY-MM-DD hh:mm:ss"'
                         - 'daily: "hh:mm"'
                         - 'weekly: "hh:mm"'
                         - 'monthly: "DD hh:mm"'
                    day_of_week:
                        type: str
                        default: 'sun'
                        description: no description
                        choices:
                            - 'unknown'
                            - 'sun'
                            - 'mon'
                            - 'tue'
                            - 'wed'
                            - 'thu'
                            - 'fri'
                            - 'sat'
                    device:
                        type: int
                        description: 'Name or id of an existing device in the database.'
                    name:
                        type: str
                        description: no description
                    run_on_db:
                        type: str
                        default: 'disable'
                        description: 'Indicates if the scheduled script should be executed on device database. It should always be disable for tcl scripts.'
                        choices:
                            - 'disable'
                            - 'enable'
                    type:
                        type: str
                        description: no description
                        choices:
                            - 'auto'
                            - 'onetime'
                            - 'daily'
                            - 'weekly'
                            - 'monthly'
            target:
                type: str
                default: 'device_database'
                description: no description
                choices:
                    - 'device_database'
                    - 'remote_device'
                    - 'adom_database'
            type:
                type: str
                description: no description
                choices:
                    - 'cli'
                    - 'tcl'
                    - 'cligrp'

'''

EXAMPLES = '''
 - hosts: fortimanager-inventory
   collections:
     - fortinet.fortimanager
   connection: httpapi
   vars:
      ansible_httpapi_use_ssl: True
      ansible_httpapi_validate_certs: False
      ansible_httpapi_port: 443
   tasks:
    - name: Script table.
      fmgr_dvmdb_script:
         bypass_validation: False
         workspace_locking_adom: <value in [global, custom adom including root]>
         workspace_locking_timeout: 300
         rc_succeeded: [0, -2, -3, ...]
         rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: <value in [present, absent]>
         dvmdb_script:
            content: <value of string>
            desc: <value of string>
            filter_build: <value of integer>
            filter_device: <value of integer>
            filter_hostname: <value of string>
            filter_ostype: <value in [unknown, fos]>
            filter_osver: <value in [unknown, 4.00, 5.00]>
            filter_platform: <value of string>
            filter_serial: <value of string>
            modification_time: <value of string>
            name: <value of string>
            script_schedule:
              -
                  datetime: <value of string>
                  day_of_week: <value in [unknown, sun, mon, ...]>
                  device: <value of integer>
                  name: <value of string>
                  run_on_db: <value in [disable, enable]>
                  type: <value in [auto, onetime, daily, ...]>
            target: <value in [device_database, remote_device, adom_database]>
            type: <value in [cli, tcl, cligrp]>

'''

RETURN = '''
request_url:
    description: The full url requested
    returned: always
    type: str
    sample: /sys/login/user
response_code:
    description: The status of api request
    returned: always
    type: int
    sample: 0
response_message:
    description: The descriptive message of the api response
    type: str
    returned: always
    sample: OK.

'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass


def main():
    jrpc_urls = [
        '/dvmdb/adom/{adom}/script',
        '/dvmdb/global/script',
        '/dvmdb/script'
    ]

    perobject_jrpc_urls = [
        '/dvmdb/adom/{adom}/script/{script}',
        '/dvmdb/global/script/{script}',
        '/dvmdb/script/{script}'
    ]

    url_params = ['adom']
    module_primary_key = 'name'
    module_arg_spec = {
        'bypass_validation': {
            'type': 'bool',
            'required': False,
            'default': False
        },
        'workspace_locking_adom': {
            'type': 'str',
            'required': False
        },
        'workspace_locking_timeout': {
            'type': 'int',
            'required': False,
            'default': 300
        },
        'rc_succeeded': {
            'required': False,
            'type': 'list'
        },
        'rc_failed': {
            'required': False,
            'type': 'list'
        },
        'state': {
            'type': 'str',
            'required': True,
            'choices': [
                'present',
                'absent'
            ]
        },
        'adom': {
            'required': True,
            'type': 'str'
        },
        'dvmdb_script': {
            'required': False,
            'type': 'dict',
            'options': {
                'content': {
                    'required': False,
                    'type': 'str'
                },
                'desc': {
                    'required': False,
                    'type': 'str'
                },
                'filter_build': {
                    'required': False,
                    'type': 'int'
                },
                'filter_device': {
                    'required': False,
                    'type': 'int'
                },
                'filter_hostname': {
                    'required': False,
                    'type': 'str'
                },
                'filter_ostype': {
                    'required': False,
                    'choices': [
                        'unknown',
                        'fos'
                    ],
                    'type': 'str'
                },
                'filter_osver': {
                    'required': False,
                    'choices': [
                        'unknown',
                        '4.00',
                        '5.00'
                    ],
                    'type': 'str'
                },
                'filter_platform': {
                    'required': False,
                    'type': 'str'
                },
                'filter_serial': {
                    'required': False,
                    'type': 'str'
                },
                'modification_time': {
                    'required': False,
                    'type': 'str'
                },
                'name': {
                    'required': True,
                    'type': 'str'
                },
                'script_schedule': {
                    'required': False,
                    'type': 'list',
                    'options': {
                        'datetime': {
                            'required': False,
                            'type': 'str'
                        },
                        'day_of_week': {
                            'required': False,
                            'choices': [
                                'unknown',
                                'sun',
                                'mon',
                                'tue',
                                'wed',
                                'thu',
                                'fri',
                                'sat'
                            ],
                            'type': 'str'
                        },
                        'device': {
                            'required': False,
                            'type': 'int'
                        },
                        'name': {
                            'required': False,
                            'type': 'str'
                        },
                        'run_on_db': {
                            'required': False,
                            'choices': [
                                'disable',
                                'enable'
                            ],
                            'type': 'str'
                        },
                        'type': {
                            'required': False,
                            'choices': [
                                'auto',
                                'onetime',
                                'daily',
                                'weekly',
                                'monthly'
                            ],
                            'type': 'str'
                        }
                    }
                },
                'target': {
                    'required': False,
                    'choices': [
                        'device_database',
                        'remote_device',
                        'adom_database'
                    ],
                    'type': 'str'
                },
                'type': {
                    'required': False,
                    'choices': [
                        'cli',
                        'tcl',
                        'cligrp'
                    ],
                    'type': 'str'
                }
            }

        }
    }

    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'dvmdb_script'),
                           supports_check_mode=False)

    fmgr = None
    if module._socket_path:
        connection = Connection(module._socket_path)
        fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
        fmgr.validate_parameters(params_validation_blob)
        fmgr.process_curd()
    else:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()

==> ansible-4.1.0-1-any.pkg.tar.xz: usr/lib/python3.9/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_dvmdb_script.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2021 Fortinet, Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_dvmdb_script
short_description: Script table.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.10"
author:
    - Link Zheng (@chillancezen)
    - Jie Xue (@JieX19)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded

options:
    enable_log:
        description: Enable/Disable logging for task
        required: false
        type: bool
        default: false
    proposed_method:
        description: The overridden method for the underlying Json RPC request
        required: false
        type: str
        choices:
          - update
          - set
          - add
    bypass_validation:
        description: only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters
        required: false
        type: bool
        default: false
    workspace_locking_adom:
        description: the adom to lock for FortiManager running in workspace mode, the value can be global and others including root
        required: false
        type: str
    workspace_locking_timeout:
        description: the maximum time in seconds to wait for other user to release the workspace lock
        required: false
        type: int
        default: 300
    state:
        description: the directive to create, update or delete an object
        type: str
        required: true
        choices:
          - present
          - absent
    rc_succeeded:
        description: the rc codes list with which the conditions to succeed will be overriden
        type: list
        required: false
    rc_failed:
        description: the rc codes list with which the conditions to fail will be overriden
        type: list
        required: false
    adom:
        description: the parameter (adom) in requested url
        type: str
        required: true
    dvmdb_script:
        description: the top level parameters set
        required: false
        type: dict
        suboptions:
            content:
                type: str
                description: 'The full content of the script result log.'
            desc:
                type: str
                description: no description
            filter_build:
                type: int
                description: 'The value will be ignored in add/set/update requests if filter_ostype is not set. It has no effect if target is "adom_database".'
            filter_device:
                type: int
                description: 'Name or id of an existing device in the database. It has no effect if target is "adom_database".'
            filter_hostname:
                type: str
                description: 'The value has no effect if target is "adom_database".'
            filter_ostype:
                type: str
                default: 'unknown'
                description: 'The value has no effect if target is "adom_database".'
                choices:
                    - 'unknown'
                    - 'fos'
            filter_osver:
                type: str
                default: 'unknown'
                description: 'The value will be ignored in add/set/update requests if filter_ostype is not set. It has no effect if target is "adom_database".'
                choices:
                    - 'unknown'
                    - '4.00'
                    - '5.00'
            filter_platform:
                type: str
                description: 'The value will be ignored in add/set/update requests if filter_ostype is not set. It has no effect if target is "adom_database".'
            filter_serial:
                type: str
                description: 'The value has no effect if target is "adom_database".'
            modification_time:
                type: str
                description: 'It is a read-only attribute indicating the time when the script was created or modified. The value will be ignored in add/set/...'
            name:
                type: str
                description: no description
            script_schedule:
                description: no description
                type: list
                suboptions:
                    datetime:
                        type: str
                        description:
                         - 'Indicates the date and time of the schedule. It should follow the following format for each scheduling type:'
                         - 'onetime: "YYYY-MM-DD hh:mm:ss"'
                         - 'daily: "hh:mm"'
                         - 'weekly: "hh:mm"'
                         - 'monthly: "DD hh:mm"'
                    day_of_week:
                        type: str
                        default: 'sun'
                        description: no description
                        choices:
                            - 'unknown'
                            - 'sun'
                            - 'mon'
                            - 'tue'
                            - 'wed'
                            - 'thu'
                            - 'fri'
                            - 'sat'
                    device:
                        type: int
                        description: 'Name or id of an existing device in the database.'
                    name:
                        type: str
                        description: no description
                    run_on_db:
                        type: str
                        default: 'disable'
                        description: 'Indicates if the scheduled script should be executed on device database. It should always be disable for tcl scripts.'
                        choices:
                            - 'disable'
                            - 'enable'
                    type:
                        type: str
                        description: no description
                        choices:
                            - 'auto'
                            - 'onetime'
                            - 'daily'
                            - 'weekly'
                            - 'monthly'
            target:
                type: str
                default: 'device_database'
                description: no description
                choices:
                    - 'device_database'
                    - 'remote_device'
                    - 'adom_database'
            type:
                type: str
                description: no description
                choices:
                    - 'cli'
                    - 'tcl'
                    - 'cligrp'

'''

EXAMPLES = '''
 - hosts: fortimanager-inventory
   collections:
     - fortinet.fortimanager
   connection: httpapi
   vars:
      ansible_httpapi_use_ssl: True
      ansible_httpapi_validate_certs: False
      ansible_httpapi_port: 443
   tasks:
    - name: Script table.
      fmgr_dvmdb_script:
         bypass_validation: False
         workspace_locking_adom: <value in [global, custom adom including root]>
         workspace_locking_timeout: 300
         rc_succeeded: [0, -2, -3, ...]
         rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: <value in [present, absent]>
         dvmdb_script:
            content: <value of string>
            desc: <value of string>
            filter_build: <value of integer>
            filter_device: <value of integer>
            filter_hostname: <value of string>
            filter_ostype: <value in [unknown, fos]>
            filter_osver: <value in [unknown, 4.00, 5.00]>
            filter_platform: <value of string>
            filter_serial: <value of string>
            modification_time: <value of string>
            name: <value of string>
            script_schedule:
              -
                  datetime: <value of string>
                  day_of_week: <value in [unknown, sun, mon, ...]>
                  device: <value of integer>
                  name: <value of string>
                  run_on_db: <value in [disable, enable]>
                  type: <value in [auto, onetime, daily, ...]>
            target: <value in [device_database, remote_device, adom_database]>
            type: <value in [cli, tcl, cligrp]>

'''

RETURN = '''
request_url:
    description: The full url requested
    returned: always
    type: str
    sample: /sys/login/user
response_code:
    description: The status of api request
    returned: always
    type: int
    sample: 0
response_message:
    description: The descriptive message of the api response
    type: str
    returned: always
    sample: OK.

'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass


def main():
    jrpc_urls = [
        '/dvmdb/adom/{adom}/script',
        '/dvmdb/global/script',
        '/dvmdb/script'
    ]

    perobject_jrpc_urls = [
        '/dvmdb/adom/{adom}/script/{script}',
        '/dvmdb/global/script/{script}',
        '/dvmdb/script/{script}'
    ]

    url_params = ['adom']
    module_primary_key = 'name'
    module_arg_spec = {
        'enable_log': {
            'type': 'bool',
            'required': False,
            'default': False
        },
        'proposed_method': {
            'type': 'str',
            'required': False,
            'choices': [
                'set',
                'update',
                'add'
            ]
        },
        'bypass_validation': {
            'type': 'bool',
            'required': False,
            'default': False
        },
        'workspace_locking_adom': {
            'type': 'str',
            'required': False
        },
        'workspace_locking_timeout': {
            'type': 'int',
            'required': False,
            'default': 300
        },
        'rc_succeeded': {
            'required': False,
            'type': 'list'
        },
        'rc_failed': {
            'required': False,
            'type': 'list'
        },
        'state': {
            'type': 'str',
            'required': True,
            'choices': [
                'present',
                'absent'
            ]
        },
        'adom': {
            'required': True,
            'type': 'str'
        },
        'dvmdb_script': {
            'required': False,
            'type': 'dict',
            'options': {
                'content': {
                    'required': False,
                    'type': 'str'
                },
                'desc': {
                    'required': False,
                    'type': 'str'
                },
                'filter_build': {
                    'required': False,
                    'type': 'int'
                },
                'filter_device': {
                    'required': False,
                    'type': 'int'
                },
                'filter_hostname': {
                    'required': False,
                    'type': 'str'
                },
                'filter_ostype': {
                    'required': False,
                    'choices': [
                        'unknown',
                        'fos'
                    ],
                    'type': 'str'
                },
                'filter_osver': {
                    'required': False,
                    'choices': [
                        'unknown',
                        '4.00',
                        '5.00'
                    ],
                    'type': 'str'
                },
                'filter_platform': {
                    'required': False,
                    'type': 'str'
                },
                'filter_serial': {
                    'required': False,
                    'type': 'str'
                },
                'modification_time': {
                    'required': False,
                    'type': 'str'
                },
                'name': {
                    'required': True,
                    'type': 'str'
                },
                'script_schedule': {
                    'required': False,
                    'type': 'list',
                    'options': {
                        'datetime': {
                            'required': False,
                            'type': 'str'
                        },
                        'day_of_week': {
                            'required': False,
                            'choices': [
                                'unknown',
                                'sun',
                                'mon',
                                'tue',
                                'wed',
                                'thu',
                                'fri',
                                'sat'
                            ],
                            'type': 'str'
                        },
                        'device': {
                            'required': False,
                            'type': 'int'
                        },
                        'name': {
                            'required': False,
                            'type': 'str'
                        },
                        'run_on_db': {
                            'required': False,
                            'choices': [
                                'disable',
                                'enable'
                            ],
                            'type': 'str'
                        },
                        'type': {
                            'required': False,
                            'choices': [
                                'auto',
                                'onetime',
                                'daily',
                                'weekly',
                                'monthly'
                            ],
                            'type': 'str'
                        }
                    }
                },
                'target': {
                    'required': False,
                    'choices': [
                        'device_database',
                        'remote_device',
                        'adom_database'
                    ],
                    'type': 'str'
                },
                'type': {
                    'required': False,
                    'choices': [
                        'cli',
                        'tcl',
                        'cligrp'
                    ],
                    'type': 'str'
                }
            }

        }
    }

    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'dvmdb_script'),
                           supports_check_mode=False)

    fmgr = None
    if module._socket_path:
        connection = Connection(module._socket_path)
        connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
        fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
        fmgr.validate_parameters(params_validation_blob)
        fmgr.process_curd()
    else:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()
